Enumerates commands that can be sent to the controller that accept a slice argument buffer. This
is separated from Command so that the lifetime parameter of the argument buffer slice does
not pervade code which never invokes these two commands.
The address increment orientation when writing image data. This configures how the controller
will auto-increment the row and column addresses when image data is written using the
WriteImageData command.